from pydantic import BaseModel, EmailStr
from typing import Optional
from datetime import datetime


class GymBase(BaseModel):
    name: str
    description: Optional[str] = None
    address: str
    city: str
    state: str
    phone: Optional[str] = None
    email: Optional[EmailStr] = None


class GymCreate(GymBase):
    pass


class GymUpdate(BaseModel):
    name: Optional[str] = None
    description: Optional[str] = None
    address: Optional[str] = None
    city: Optional[str] = None
    state: Optional[str] = None
    phone: Optional[str] = None
    email: Optional[EmailStr] = None


class GymInDB(GymBase):
    id: int
    is_active: bool
    created_at: datetime
    updated_at: datetime

    class Config:
        from_attributes = True


class Gym(GymInDB):
    pass
